==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/gui/CustomChestBlockGui.java <==
package cc.thonly.reverie_dreams.gui;

import cc.thonly.reverie_dreams.block.CashBoxBlock;
import cc.thonly.reverie_dreams.block.CustomChestBlock;
import cc.thonly.reverie_dreams.block.entity.CustomChestBlockEntity;
import cc.thonly.reverie_dreams.item.ModItems;
import cc.thonly.reverie_dreams.util.PredicateSlot;
import eu.pb4.sgui.api.gui.SimpleGui;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Supplier;
import net.minecraft.class_1263;
import net.minecraft.class_1735;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3917;


public class CustomChestBlockGui extends SimpleGui implements GuiCommon {
    public static final List<class_1792> COIN_ITEMS = new ArrayList<>(List.of(
            ModItems.COPPER_COIN,
            ModItems.SILVER_COIN,
            ModItems.GOLD_COIN
    ));
    private final class_2248 block;
    private final CustomChestBlockEntity chestBlockEntity;
    private final class_2338 blockPos;
    private final SlotFactory factory;

    public CustomChestBlockGui(class_2248 block, CustomChestBlockEntity chestBlockEntity, class_3222 player, SlotFactory factory) {
        super(class_3917.field_17326, player, false);
        this.block = block;
        this.chestBlockEntity = chestBlockEntity;
        this.blockPos = chestBlockEntity.method_11016();
        this.factory = factory;
        this.setTitle(class_2561.method_43471(block.method_63499()));
        this.init();
    }

    @Override
    public void onTick() {
        super.onTick();
        class_3218 world = this.player.method_51469();
        if (!(world.method_8320(this.blockPos).method_26204() instanceof CustomChestBlock) && !(world.method_8320(this.blockPos).method_26204() instanceof CashBoxBlock)) {
            this.close();
        }
    }

    @Override
    public void init() {
        for (int i = 0; i < this.chestBlockEntity.method_5439(); i++) {
            this.setSlotRedirect(i, this.factory.get(this.chestBlockEntity.getInventory(), i, 0, 0));
        }
    }

    @Override
    public void onOpen() {
        super.onOpen();
        this.player.method_56078(class_3417.field_14982);
    }

    @Override
    public void onClose() {
        super.onClose();
        this.chestBlockEntity.method_5431();
    }

    public interface SlotFactory {
        class_1735 get(class_1263 inventory, int index, int x, int y);
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/gui/CustomChestBlockGui.java <==
package cc.thonly.reverie_dreams.gui;

import cc.thonly.reverie_dreams.block.CashBoxBlock;
import cc.thonly.reverie_dreams.block.CustomChestBlock;
import cc.thonly.reverie_dreams.block.entity.CustomChestBlockEntity;
import cc.thonly.reverie_dreams.registry.content.item.RDItems;
import eu.pb4.sgui.api.gui.SimpleGui;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1263;
import net.minecraft.class_1735;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3917;


public class CustomChestBlockGui extends SimpleGui implements GuiCommon {
    public static final List<class_1792> COIN_ITEMS = new ArrayList<>(List.of(
            RDItems.COPPER_COIN,
            RDItems.SILVER_COIN,
            RDItems.GOLD_COIN
    ));
    private final class_2248 block;
    private final CustomChestBlockEntity chestBlockEntity;
    private final class_2338 blockPos;
    private final SlotFactory factory;

    public CustomChestBlockGui(class_2248 block, CustomChestBlockEntity chestBlockEntity, class_3222 player, SlotFactory factory) {
        super(class_3917.field_17326, player, false);
        this.block = block;
        this.chestBlockEntity = chestBlockEntity;
        this.blockPos = chestBlockEntity.method_11016();
        this.factory = factory;
        this.setTitle(class_2561.method_43471(block.method_63499()));
        this.init();
    }

    @Override
    public void onTick() {
        super.onTick();
        class_3218 world = this.player.method_51469();
        if (!(world.method_8320(this.blockPos).method_26204() instanceof CustomChestBlock) && !(world.method_8320(this.blockPos).method_26204() instanceof CashBoxBlock)) {
            this.close();
        }
    }

    @Override
    public void init() {
        for (int i = 0; i < this.chestBlockEntity.method_5439(); i++) {
            this.setSlotRedirect(i, this.factory.get(this.chestBlockEntity.getInventory(), i, 0, 0));
        }
    }

    @Override
    public void onOpen() {
        super.onOpen();
        this.player.method_56078(class_3417.field_14982);
    }

    @Override
    public void onClose() {
        super.onClose();
        this.chestBlockEntity.method_5431();
    }

    public interface SlotFactory {
        class_1735 get(class_1263 inventory, int index, int x, int y);
    }
}
